pub struct Gateway { /* private fields */ }Expand description
Connectivity boundary for one or more procs.
Implementations
Sourceimpl Gateway
impl Gateway
Sourcepub fn default_location(&self) -> Location
pub fn default_location(&self) -> Location
The gateway’s default advertised location.
Sourcepub fn set_default_location(&self, location: Location)
pub fn set_default_location(&self, location: Location)
Set the gateway’s default advertised location.
Sourcepub fn proc_addr(&self, proc_id: &ProcId) -> ProcAddr
pub fn proc_addr(&self, proc_id: &ProcId) -> ProcAddr
Construct a routeable proc address using this gateway’s default location.
Sourcepub fn serve(
&self,
addr: ChannelAddr,
) -> Result<GatewayServeHandle, ChannelError>
pub fn serve( &self, addr: ChannelAddr, ) -> Result<GatewayServeHandle, ChannelError>
Serve this gateway on the provided channel address.
When serving the first local ChannelAddr::any address, the gateway
binds the local address that was reserved when the gateway was created.
Local reservation is separate from local binding so a gateway can have a
stable location before it has a runtime available to run a server.
Later local any serves allocate fresh local ports, so the gateway can
have multiple active local servers.
Serving updates the gateway’s default location to the newly served address. When that server stops, the default location falls back to the previous active server, or to the reserved fallback location when no server remains.